# Autogenerated by nbdev

d = {
    "settings": {
        "branch": "master",
        "doc_baseurl": "/pygments-sb-nrql/",
        "doc_host": "https://dynovaio.github.io",
        "git_url": "https://github.com/dynova/pygments-sb-nrql/tree/master/",
        "lib_path": "src/pygments_sb_nrql",
    },
    "syms": {
        "pygments_sb_nrql.builtins": {},
        "pygments_sb_nrql.lexer": {
            "pygments_sb_nrql.lexer.NrqlLexer": (
                "lexer.html#nrqllexer",
                "pygments_sb_nrql/lexer.py",
            )
        },
        "pygments_sb_nrql.version": {},
    },
}
